==> dde-control-center_6.0.20.tar.xz: BUILD/src/plugin-display/operation/displaydbusproxy.cpp <==
//SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
//
//SPDX-License-Identifier: GPL-3.0-or-later
#include "displaydbusproxy.h"
#include "widgets/dccdbusinterface.h"

#include <QDBusInterface>
#include <QDBusPendingReply>
#include <QDBusMetaType>

const static QString DisplayService = "org.deepin.dde.Display1";
const static QString DisplayPath = "/org/deepin/dde/Display1";
const static QString DisplayInterface = "org.deepin.dde.Display1";

const static QString AppearanceService = "org.deepin.dde.Appearance1";
const static QString AppearancePath = "/org/deepin/dde/Appearance1";
const static QString AppearanceInterface = "org.deepin.dde.Appearance1";

const static QString PowerService = "org.deepin.dde.Power1";
const static QString PowerPath = "/org/deepin/dde/Power1";
const static QString PowerInterface = "org.deepin.dde.Power1";

const static QString CooperationService = "org.deepin.dde.Cooperation1";
const static QString CooperationPath = "/org/deepin/dde/Cooperation1";
const static QString CooperationInterface = "org.deepin.dde.Cooperation1";

DisplayDBusProxy::DisplayDBusProxy(QObject *parent)
    : QObject(parent)
{
    registerTouchscreenInfoList_V2MetaType();
    registerTouchscreenMapMetaType();
    registerResolutionListMetaType();
    registerBrightnessMapMetaType();
    registerTouchscreenInfoListMetaType();
    registerScreenRectMetaType();
    registerResolutionMetaType();

    init();
}

void DisplayDBusProxy::init()
{
    m_dBusSystemDisplayInter = new DCC_NAMESPACE::DCCDBusInterface("org.deepin.dde.Display1", "/org/deepin/dde/Display1", "org.deepin.dde.Display1", QDBusConnection::systemBus(), this);
    m_dBusDisplayInter = new DCC_NAMESPACE::DCCDBusInterface(DisplayService, DisplayPath, DisplayInterface, QDBusConnection::sessionBus(), this);
    m_dBusAppearanceInter = new DCC_NAMESPACE::DCCDBusInterface(AppearanceService, AppearancePath, AppearanceInterface, QDBusConnection::sessionBus(), this);
    m_dBusPowerInter = new DCC_NAMESPACE::DCCDBusInterface(PowerService, PowerPath, PowerInterface, QDBusConnection::sessionBus(), this);
    m_dBusCooperationInter = new DCC_NAMESPACE::DCCDBusInterface(CooperationService, CooperationPath, CooperationInterface, QDBusConnection::sessionBus(), this);
}

//power
bool DisplayDBusProxy::ambientLightAdjustBrightness()
{
    return qvariant_cast<bool>(m_dBusPowerInter->property("AmbientLightAdjustBrightness"));
}

void DisplayDBusProxy::setAmbientLightAdjustBrightness(bool value)
{
    m_dBusPowerInter->setProperty("AmbientLightAdjustBrightness", QVariant::fromValue(value));
}

bool DisplayDBusProxy::hasAmbientLightSensor()
{
    return qvariant_cast<bool>(m_dBusPowerInter->property("HasAmbientLightSensor"));
}

QList<QDBusObjectPath> DisplayDBusProxy::Machines()
{
    return qvariant_cast<QList<QDBusObjectPath>>(m_dBusCooperationInter->property("Machines"));
}

QList<QString> DisplayDBusProxy::CooperatedMachines()
{
    QDBusInterface in("org.deepin.dde.Cooperation1", "/org/deepin/dde/Cooperation1", "org.deepin.dde.Cooperation1", QDBusConnection::sessionBus());
    return in.property("CooperatedMachines").toStringList();
}

bool DisplayDBusProxy::deviceSharingSwitch()
{
    return qvariant_cast<bool>(m_dBusCooperationInter->property("DeviceSharingSwitch"));
}

void DisplayDBusProxy::setDeviceSharingSwitch(const bool enable)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(enable);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("SetDeviceSharingSwitch"), argumentList);
}

void DisplayDBusProxy::setOpenSharedClipboard(bool on)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(on);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("OpenSharedClipboard"), argumentList);
}

bool DisplayDBusProxy::sharedClipboard()
{
    return qvariant_cast<bool>(m_dBusCooperationInter->property("SharedClipboard"));
}

void DisplayDBusProxy::setFilesStoragePath(const QString &path)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(path);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("SetFilesStoragePath"), argumentList);
}

QString DisplayDBusProxy::filesStoragePath()
{
    return qvariant_cast<QString>(m_dBusCooperationInter->property("FilesStoragePath"));
}

void DisplayDBusProxy::setOpenSharedDevices(bool on)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(on);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("OpenSharedDevices"), argumentList);
}

bool DisplayDBusProxy::sharedDevices()
{
    return qvariant_cast<bool>(m_dBusCooperationInter->property("SharedDevices"));
}

//display
BrightnessMap DisplayDBusProxy::brightness()
{
    return qvariant_cast<BrightnessMap>(m_dBusDisplayInter->property("Brightness"));
}

int DisplayDBusProxy::colorTemperatureManual()
{
    return qvariant_cast<int>(m_dBusDisplayInter->property("ColorTemperatureManual"));
}

int DisplayDBusProxy::colorTemperatureMode()
{
    return qvariant_cast<int>(m_dBusDisplayInter->property("ColorTemperatureMode"));
}

QString DisplayDBusProxy::currentCustomId()
{
    return qvariant_cast<QString>(m_dBusDisplayInter->property("CurrentCustomId"));
}

QStringList DisplayDBusProxy::customIdList()
{
    return qvariant_cast<QStringList>(m_dBusDisplayInter->property("CustomIdList"));
}

uchar DisplayDBusProxy::displayMode()
{
    return qvariant_cast<uchar>(m_dBusDisplayInter->property("DisplayMode"));
}
bool DisplayDBusProxy::hasChanged()
{
    return qvariant_cast<bool>(m_dBusDisplayInter->property("HasChanged"));
}

uint DisplayDBusProxy::maxBacklightBrightness()
{
    return qvariant_cast<uint>(m_dBusDisplayInter->property("MaxBacklightBrightness"));
}

QList<QDBusObjectPath> DisplayDBusProxy::monitors()
{
    return qvariant_cast<QList<QDBusObjectPath>>(m_dBusDisplayInter->property("Monitors"));
}

QString DisplayDBusProxy::primary()
{
    return qvariant_cast<QString>(m_dBusDisplayInter->property("Primary"));
}

ScreenRect DisplayDBusProxy::primaryRect()
{
    return qvariant_cast<ScreenRect>(m_dBusDisplayInter->property("PrimaryRect"));
}

ushort DisplayDBusProxy::screenHeight()
{
    return qvariant_cast<ushort>(m_dBusDisplayInter->property("ScreenHeight"));
}

ushort DisplayDBusProxy::screenWidth()
{
    return qvariant_cast<ushort>(m_dBusDisplayInter->property("ScreenWidth"));
}

TouchscreenMap DisplayDBusProxy::touchMap()
{
    return qvariant_cast<TouchscreenMap>(m_dBusDisplayInter->property("TouchMap"));
}

TouchscreenInfoList DisplayDBusProxy::touchscreens()
{
    return qvariant_cast<TouchscreenInfoList>(m_dBusDisplayInter->property("Touchscreens"));
}

TouchscreenInfoList_V2 DisplayDBusProxy::touchscreensV2()
{
    return qvariant_cast<TouchscreenInfoList_V2>(m_dBusDisplayInter->property("TouchscreensV2"));
}


QDBusPendingReply<double> DisplayDBusProxy::GetScaleFactor()
{
    QList<QVariant> argumentList;
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("GetScaleFactor"), argumentList);
}

QDBusPendingReply<QMap<QString,double> > DisplayDBusProxy::GetScreenScaleFactors()
{
    QList<QVariant> argumentList;
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("GetScreenScaleFactors"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetScaleFactor(double in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("SetScaleFactor"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetScreenScaleFactors(const QMap<QString,double> &scaleFactors)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(scaleFactors);
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("SetScreenScaleFactors"), argumentList);
}

QString DisplayDBusProxy::GetConfig()
{
    QList<QVariant> argumentList;
    return QDBusPendingReply<QString>(m_dBusSystemDisplayInter->asyncCallWithArgumentList(QStringLiteral("GetConfig"), argumentList));
}

void DisplayDBusProxy::SetConfig(QString cfgStr)
{
    QList<QVariant> argumentList;
    argumentList << cfgStr;
    m_dBusSystemDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetConfig"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ApplyChanges()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ApplyChanges"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::AssociateTouch(const QString &in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("AssociateTouch"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::AssociateTouchByUUID(const QString &in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("AssociateTouchByUUID"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ChangeBrightness(bool in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ChangeBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::DeleteCustomMode(const QString &in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("DeleteCustomMode"), argumentList);
}

QDBusPendingReply<uchar> DisplayDBusProxy::GetRealDisplayMode()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("GetRealDisplayMode"), argumentList);
}

QDBusPendingReply<QStringList> DisplayDBusProxy::ListOutputNames()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ListOutputNames"), argumentList);
}

QDBusPendingReply<ResolutionList> DisplayDBusProxy::ListOutputsCommonModes()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ListOutputsCommonModes"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ModifyConfigName(const QString &in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ModifyConfigName"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::RefreshBrightness()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("RefreshBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::Reset()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("Reset"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ResetChanges()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ResetChanges"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::Save()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("Save"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetAndSaveBrightness(const QString &in0, double in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetAndSaveBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetBrightness(const QString &in0, double in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetColorTemperature(int in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetColorTemperature"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetMethodAdjustCCT(int in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetMethodAdjustCCT"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetPrimary(const QString &in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetPrimary"), argumentList);
}


QDBusPendingReply<> DisplayDBusProxy::SwitchMode(uchar in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SwitchMode"), argumentList);
}

QDBusReply<bool> DisplayDBusProxy::CanSetBrightnessSync(const QString &name)
{
    return m_dBusDisplayInter->call("CanSetBrightness", name);
}

QDBusReply<bool> DisplayDBusProxy::SupportSetColorTemperatureSync()
{
    return m_dBusDisplayInter->call("SupportSetColorTemperatureSync");
}

==> dde-control-center_6.0.28.tar.xz: BUILD/src/plugin-display/operation/displaydbusproxy.cpp <==
//SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
//
//SPDX-License-Identifier: GPL-3.0-or-later
#include "displaydbusproxy.h"
#include "widgets/dccdbusinterface.h"

#include <QDBusInterface>
#include <QDBusPendingReply>
#include <QDBusMetaType>

const static QString DisplayService = "org.deepin.dde.Display1";
const static QString DisplayPath = "/org/deepin/dde/Display1";
const static QString DisplayInterface = "org.deepin.dde.Display1";

const static QString AppearanceService = "org.deepin.dde.Appearance1";
const static QString AppearancePath = "/org/deepin/dde/Appearance1";
const static QString AppearanceInterface = "org.deepin.dde.Appearance1";

const static QString PowerService = "org.deepin.dde.Power1";
const static QString PowerPath = "/org/deepin/dde/Power1";
const static QString PowerInterface = "org.deepin.dde.Power1";

const static QString CooperationService = "org.deepin.dde.Cooperation1";
const static QString CooperationPath = "/org/deepin/dde/Cooperation1";
const static QString CooperationInterface = "org.deepin.dde.Cooperation1";

DisplayDBusProxy::DisplayDBusProxy(QObject *parent)
    : QObject(parent)
{
    registerTouchscreenInfoList_V2MetaType();
    registerTouchscreenMapMetaType();
    registerResolutionListMetaType();
    registerBrightnessMapMetaType();
    registerTouchscreenInfoListMetaType();
    registerScreenRectMetaType();
    registerResolutionMetaType();

    init();
}

void DisplayDBusProxy::init()
{
    m_dBusSystemDisplayInter = new DDBusInterface("org.deepin.dde.Display1", "/org/deepin/dde/Display1", "org.deepin.dde.Display1", QDBusConnection::systemBus(), this);
    m_dBusDisplayInter = new DDBusInterface(DisplayService, DisplayPath, DisplayInterface, QDBusConnection::sessionBus(), this);
    m_dBusAppearanceInter = new DDBusInterface(AppearanceService, AppearancePath, AppearanceInterface, QDBusConnection::sessionBus(), this);
    m_dBusPowerInter = new DDBusInterface(PowerService, PowerPath, PowerInterface, QDBusConnection::sessionBus(), this);
    m_dBusCooperationInter = new DDBusInterface(CooperationService, CooperationPath, CooperationInterface, QDBusConnection::sessionBus(), this);
}

//power
bool DisplayDBusProxy::ambientLightAdjustBrightness()
{
    return qvariant_cast<bool>(m_dBusPowerInter->property("AmbientLightAdjustBrightness"));
}

void DisplayDBusProxy::setAmbientLightAdjustBrightness(bool value)
{
    m_dBusPowerInter->setProperty("AmbientLightAdjustBrightness", QVariant::fromValue(value));
}

bool DisplayDBusProxy::hasAmbientLightSensor()
{
    return qvariant_cast<bool>(m_dBusPowerInter->property("HasAmbientLightSensor"));
}

QList<QDBusObjectPath> DisplayDBusProxy::Machines()
{
    return qvariant_cast<QList<QDBusObjectPath>>(m_dBusCooperationInter->property("Machines"));
}

QList<QString> DisplayDBusProxy::CooperatedMachines()
{
    QDBusInterface in("org.deepin.dde.Cooperation1", "/org/deepin/dde/Cooperation1", "org.deepin.dde.Cooperation1", QDBusConnection::sessionBus());
    return in.property("CooperatedMachines").toStringList();
}

bool DisplayDBusProxy::deviceSharingSwitch()
{
    return qvariant_cast<bool>(m_dBusCooperationInter->property("DeviceSharingSwitch"));
}

void DisplayDBusProxy::setDeviceSharingSwitch(const bool enable)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(enable);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("SetDeviceSharingSwitch"), argumentList);
}

void DisplayDBusProxy::setOpenSharedClipboard(bool on)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(on);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("OpenSharedClipboard"), argumentList);
}

bool DisplayDBusProxy::sharedClipboard()
{
    return qvariant_cast<bool>(m_dBusCooperationInter->property("SharedClipboard"));
}

void DisplayDBusProxy::setFilesStoragePath(const QString &path)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(path);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("SetFilesStoragePath"), argumentList);
}

QString DisplayDBusProxy::filesStoragePath()
{
    return qvariant_cast<QString>(m_dBusCooperationInter->property("FilesStoragePath"));
}

void DisplayDBusProxy::setOpenSharedDevices(bool on)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(on);
    m_dBusCooperationInter->asyncCallWithArgumentList(QStringLiteral("OpenSharedDevices"), argumentList);
}

bool DisplayDBusProxy::sharedDevices()
{
    return qvariant_cast<bool>(m_dBusCooperationInter->property("SharedDevices"));
}

//display
BrightnessMap DisplayDBusProxy::brightness()
{
    return qvariant_cast<BrightnessMap>(m_dBusDisplayInter->property("Brightness"));
}

int DisplayDBusProxy::colorTemperatureManual()
{
    return qvariant_cast<int>(m_dBusDisplayInter->property("ColorTemperatureManual"));
}

int DisplayDBusProxy::colorTemperatureMode()
{
    return qvariant_cast<int>(m_dBusDisplayInter->property("ColorTemperatureMode"));
}

QString DisplayDBusProxy::currentCustomId()
{
    return qvariant_cast<QString>(m_dBusDisplayInter->property("CurrentCustomId"));
}

QStringList DisplayDBusProxy::customIdList()
{
    return qvariant_cast<QStringList>(m_dBusDisplayInter->property("CustomIdList"));
}

uchar DisplayDBusProxy::displayMode()
{
    return qvariant_cast<uchar>(m_dBusDisplayInter->property("DisplayMode"));
}
bool DisplayDBusProxy::hasChanged()
{
    return qvariant_cast<bool>(m_dBusDisplayInter->property("HasChanged"));
}

uint DisplayDBusProxy::maxBacklightBrightness()
{
    return qvariant_cast<uint>(m_dBusDisplayInter->property("MaxBacklightBrightness"));
}

QList<QDBusObjectPath> DisplayDBusProxy::monitors()
{
    return qvariant_cast<QList<QDBusObjectPath>>(m_dBusDisplayInter->property("Monitors"));
}

QString DisplayDBusProxy::primary()
{
    return qvariant_cast<QString>(m_dBusDisplayInter->property("Primary"));
}

ScreenRect DisplayDBusProxy::primaryRect()
{
    return qvariant_cast<ScreenRect>(m_dBusDisplayInter->property("PrimaryRect"));
}

ushort DisplayDBusProxy::screenHeight()
{
    return qvariant_cast<ushort>(m_dBusDisplayInter->property("ScreenHeight"));
}

ushort DisplayDBusProxy::screenWidth()
{
    return qvariant_cast<ushort>(m_dBusDisplayInter->property("ScreenWidth"));
}

TouchscreenMap DisplayDBusProxy::touchMap()
{
    return qvariant_cast<TouchscreenMap>(m_dBusDisplayInter->property("TouchMap"));
}

TouchscreenInfoList DisplayDBusProxy::touchscreens()
{
    return qvariant_cast<TouchscreenInfoList>(m_dBusDisplayInter->property("Touchscreens"));
}

TouchscreenInfoList_V2 DisplayDBusProxy::touchscreensV2()
{
    return qvariant_cast<TouchscreenInfoList_V2>(m_dBusDisplayInter->property("TouchscreensV2"));
}


QDBusPendingReply<double> DisplayDBusProxy::GetScaleFactor()
{
    QList<QVariant> argumentList;
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("GetScaleFactor"), argumentList);
}

QDBusPendingReply<QMap<QString,double> > DisplayDBusProxy::GetScreenScaleFactors()
{
    QList<QVariant> argumentList;
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("GetScreenScaleFactors"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetScaleFactor(double in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("SetScaleFactor"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetScreenScaleFactors(const QMap<QString,double> &scaleFactors)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(scaleFactors);
    return m_dBusAppearanceInter->asyncCallWithArgumentList(QStringLiteral("SetScreenScaleFactors"), argumentList);
}

QString DisplayDBusProxy::GetConfig()
{
    QList<QVariant> argumentList;
    return QDBusPendingReply<QString>(m_dBusSystemDisplayInter->asyncCallWithArgumentList(QStringLiteral("GetConfig"), argumentList));
}

void DisplayDBusProxy::SetConfig(QString cfgStr)
{
    QList<QVariant> argumentList;
    argumentList << cfgStr;
    m_dBusSystemDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetConfig"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ApplyChanges()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ApplyChanges"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::AssociateTouch(const QString &in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("AssociateTouch"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::AssociateTouchByUUID(const QString &in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("AssociateTouchByUUID"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ChangeBrightness(bool in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ChangeBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::DeleteCustomMode(const QString &in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("DeleteCustomMode"), argumentList);
}

QDBusPendingReply<uchar> DisplayDBusProxy::GetRealDisplayMode()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("GetRealDisplayMode"), argumentList);
}

QDBusPendingReply<QStringList> DisplayDBusProxy::ListOutputNames()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ListOutputNames"), argumentList);
}

QDBusPendingReply<ResolutionList> DisplayDBusProxy::ListOutputsCommonModes()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ListOutputsCommonModes"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ModifyConfigName(const QString &in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ModifyConfigName"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::RefreshBrightness()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("RefreshBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::Reset()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("Reset"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::ResetChanges()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("ResetChanges"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::Save()
{
    QList<QVariant> argumentList;
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("Save"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetAndSaveBrightness(const QString &in0, double in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetAndSaveBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetBrightness(const QString &in0, double in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetBrightness"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetColorTemperature(int in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetColorTemperature"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetMethodAdjustCCT(int in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetMethodAdjustCCT"), argumentList);
}

QDBusPendingReply<> DisplayDBusProxy::SetPrimary(const QString &in0)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SetPrimary"), argumentList);
}


QDBusPendingReply<> DisplayDBusProxy::SwitchMode(uchar in0, const QString &in1)
{
    QList<QVariant> argumentList;
    argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
    return m_dBusDisplayInter->asyncCallWithArgumentList(QStringLiteral("SwitchMode"), argumentList);
}

QDBusReply<bool> DisplayDBusProxy::CanSetBrightnessSync(const QString &name)
{
    return m_dBusDisplayInter->call("CanSetBrightness", name);
}

QDBusReply<bool> DisplayDBusProxy::SupportSetColorTemperatureSync()
{
    return m_dBusDisplayInter->call("SupportSetColorTemperatureSync");
}
